@@ -22,13 +22,9 @@
 
 int main(int argc, char** argv)
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-#endif
-
     QApplication app(argc, argv);
 
-    KLocalizedString::setApplicationDomain("kuiviewer");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("kuiviewer"));
 
     KAboutData about(QStringLiteral("kuiviewer"), i18n("KUIViewer"),
                      QStringLiteral(KUIVIEWER_VERSION_STRING),
